@@ -180,7 +180,8 @@ def main():
             # and URLs
             if not (
                 sequence
-                and sequence[-1] in ["wait", "seek", "sleep", "sleep_timer", "sleep_at"]
+                and sequence[-1]
+                in ["wait", "wait_until", "seek", "sleep", "sleep_timer", "sleep_at"]
                 or ":/" in arg
             ):
                 error_and_exit(
@@ -217,6 +218,18 @@ def main():
                         "'wait' requires float number of hours, seconds or minutes + 'h/m/s'"
                     )
                 continue
+            elif speaker_name in ["wait_until"]:
+                if len(sequence) != 2:
+                    error_and_exit("'wait_until' requires 1 parameter")
+                try:
+                    duration = ap.seconds_until(action)
+                    logging.info("Waiting for {}s".format(duration))
+                    time.sleep(duration)
+                except ValueError:
+                    error_and_exit(
+                        "'wait_until' requires parameter: time in 24hr HH:MM format"
+                    )
+                continue
             args = sequence[2:]
             speaker = get_speaker(speaker_name, use_local_speaker_list)
             if not speaker:
