@@ -5,10 +5,11 @@ import socket
 import soco
 import ifaddr
 import threading
-import pprint
+import logging
 import tabulate
 from collections import namedtuple
 
+
 # Type for holding speaker details
 SonosDevice = namedtuple(
     "SonosDevice",
@@ -34,7 +35,7 @@ class Speakers:
         save_directory=None,
         save_file=None,
         network_threads=128,
-        network_timeout=10.0,
+        network_timeout=2.0,
     ):
         self._save_directory = (
             save_directory
@@ -53,6 +54,7 @@ class Speakers:
         for old_file in ["speakers.pickle"]:
             pathname = self._save_directory + old_file
             if os.path.exists(pathname):
+                logging.info("Removing old local speaker cache {}".format(pathname))
                 # print("Removing deprecated local speaker file:", pathname)
                 os.remove(pathname)
 
@@ -215,6 +217,7 @@ class Speakers:
                 device = Speakers.get_sonos_device_data(ip_addr, soco_timeout)
                 if device:
                     sonos_devices.append(device)
+                    logging.info("Found Sonos device at: {}".format(device.ip_address))
 
     def discover(self):
         """Discover the Sonos speakers on the network(s) to which
@@ -240,13 +243,34 @@ class Speakers:
                         self._speakers,
                     ),
                 )
-            except:
+            except RuntimeError:
                 break
             thread_list.append(thread)
             thread.start()
+        logging.info("Created {} threads for network scan".format(len(thread_list)))
         # Wait for all threads to finish before returning
         for thread in thread_list:
             thread.join()
+        # Finally, for each household ID, check that all zones have been recorded
+        # using zone information obtained from Sonos
+        households = []
+        for speaker in self._speakers:
+            if speaker.household_id not in households:
+                households.append(speaker.household_id)
+                try:
+                    for zone in soco.SoCo(speaker.ip_address).all_zones:
+                        device = Speakers.get_sonos_device_data(
+                            zone.ip_address, self._network_timeout
+                        )
+                        if not device in self._speakers:
+                            logging.info(
+                                "Group discovery found additional speaker at {}".format(
+                                    device.ip_address
+                                )
+                            )
+                            self._speakers.append(device)
+                except:
+                    pass
 
     def find(self, speaker_name, require_visible=True):
         """Find a speaker by name and return its SoCo object."""
@@ -306,7 +330,7 @@ class Speakers:
             "IP Address",
             "Device Model",
             "Visibility",
-            "SW Vers.",
+            "SW Version",
         ]
         for household in households:
             print()
@@ -319,5 +343,5 @@ class Speakers:
             print()
 
         print("{} Sonos Household(s) found".format(len(households)))
-        print("{} Sonos devices found".format(num_devices))
+        print("{} Sonos device(s) found".format(num_devices))
         print()
